/*
 * Copyright (c) 2006 AWS Convergence Technologies, Inc. 
 * All rights reserved.
 * Visit http://www.aws.com
 *
 * WBProgressAnimator.js
 *
 * This scripts contains the WBProgressAnimator resuable class. A WBProgressAnimator
 * animates our progress during a task (such as a search.)
 */
 
 // Object definition
function WBProgressAnimator(div,steps,delay,path)
{
	this.progressDiv = div;       // the element that we're animating
	this.totalSteps = steps;      // the total number of animation steps
	this.delayTime = delay;       // time in miliseconds between animation steps
	this.path = path;             // path to the progress indicator images folder without the trailing '/'
	this.currentStep = 0;         // sets the current animation being step to 0
	this.finishStep = steps - 1;  // sets the last step
	this.duration = steps*delay;     // the total length of one full animation
	this.animating = false;       // current state of animating
	var self = this;              // fixes scope problems
	this.progressAnimator = null; // the animation object

	// Set the initial conditions of the layer
	this.progressDiv.style.setProperty("opacity","0");
	this.progressDiv.style.setProperty("background-image","url("+path+"/0.png)");
			
	// AppleAnimation callback; this is where we actually change the rotation
	this.nextFrame = function (animation, now, first, done) {
		if(self.animating)
		{
			self.currentStep++;
			if(self.currentStep > self.finishStep) { self.currentStep = 0; }
			self.progressDiv.style.setProperty("background-image","url("+self.path+"/"+self.currentStep+".png)");
		}
		else { self.doneAnimating; }
	}
	
	// Callback for AppleAnimator; also called to interrupt an active progress-animation
	this.doneAnimating = function () {
		if(self.animating)
		{
			self.progressAnimator.stop();
			delete self.progressAnimator;
			self.currentStep = 0;
			self.progressDiv.style.setProperty("background-image","url("+self.path+"/0.png)");
			self.start();
		}
		else
		{
			self.progressDiv.style.setProperty("opacity","0");
			self.progressDiv.style.setProperty("background-image","url("+self.path+"/0.png)");
			delete self.progressAnimator;
		}
	}
}

// Do not call this function directly, only from an initialized WBProgressAnimator object.
// This starts the whole animation process.
WBProgressAnimator.prototype.start = function ()
{
	if (this.progressAnimator) {
		this.progressAnimator.stop();
		this.doneAnimating();
	}
		
	this.progressAnimator = new AppleAnimator(this.duration, this.delayTime, this.currentStep, this.finishStep, this.nextFrame);
	this.progressAnimator.oncomplete = this.doneAnimating;
	this.animating = true;
	this.progressDiv.style.setProperty("opacity","1");
	this.progressAnimator.start();
}

WBProgressAnimator.prototype.stop = function ()
{
	this.animating = false;
}