/*
 * Copyright (c) 2006 AWS Convergence Technologies, Inc. 
 * All rights reserved.
 * Visit http://www.aws.com
 *
 * WBDataLocation.js
 *
 * This scripts contains the WBDataLocations resuable class. A WBDataLocations object
 * takes care of loading and holding references for the design information such as
 * data URLs, landing page URLs, and important messages for the user.
 */

// Object Definition
function WBDataLocations(loadCallback,errorCallback,errorString,shortErrorWaitTime,longErrorWaitTime,URL,preferences,version)
{
	this.time = new WBTime(); // New time object
	this.lastReload; // Last time the data was successfully updated or max allowed errors were reached
	this.updateRate = 21600*1000; // Rate at which the data should be updated in miliseconds

	this.returnedGUID; // Returned GUID
	this.pid;          // PID

	this.locationURL;  // URL for location searching
	this.stationURL;   // URL for station searching
	this.liveDataURL;  // URL for live data ISAPI	
	this.forecastDataURL;  // URL for foreacst datafeed
	this.radarDataURL;  // URL for radar datafeed
	this.alertsDataURL;  // URL for alerts datafeed
	this.camsDataURL;
	this.moreTabContentURL;
	this.linkRedirectURL;
	
	this.newVersionAvailable;       // 0 if no, 1 if yes
	this.newVersionDownloadURL;     // Page where the user can download a new version
	
	this.forecastMinUpdateRate;		// Foreacst Data Min Update Rate
	this.forecastMaxUpdateRate;		// Foreacst Data Max Update Rate
	this.radarMinUpdateRate;        // Radar Data Min Update Rate
	this.radarMaxUpdateRate;        // Radar Data Max Update Rate
	this.newsMinUpdateRate;			// News Data Min Update Rate
	this.newsMaxUpdateRate;			// News Data Max Update Rate
	this.alertsMinUpdateRate;		// Alerts Data Min Update Rate
	this.alertsMaxUpdateRate;		// Alerts Data Max Update Rate
	this.liveMinUpdateRate;			// Live Data Min Update Rate
	this.liveMaxUpdateRate;			// Live Data Max Update Rate
	
	this.stateswitchtimer;			// Time between active/inactive switching
	this.dataErrorShortWaitTime;    // Data error short wait timeout
	this.dataErrorLongWaitTime;     // Data error long wait timeout


	this.loadCallback = loadCallback;		      // Data Loaded Callback
	this.loadErrorCallback = errorCallback;       // Data Error Callback
	this.errorString = errorString;               // String passed to the reload timer
	this.shortErrorWaitTime = shortErrorWaitTime; // Timeout for short error
	this.longErrorWaitTime = longErrorWaitTime;   // Timeout for long error
	this.errorCount = 0;                          // Counts the number of internal loading errors
	this.dataLoadedCorrectly = false;             // BOOL to see if we have correct data in the object or not

	URL = URL + "?version=" + version;
	
	var prefGUID = preferences.getGUID();
	if(prefGUID)
	{
		if(prefGUID.length == 36 && prefGUID.indexOf("-") == 8 && prefGUID.lastIndexOf("-") == 23)
		{
			URL = URL + "&uid=" + preferences.getGUID();
		}
	}

	// WBDataRequest object. Does the work in loading data from the ISAPI.
	this.data = new WBDataRequest(URL,this.dataFetched);
	
	this.prefs = preferences;
	this.dataFetched.currentScope = this; // Used when the dataFetched function has lost scope.
}

// Do not call this directly, only from an initialized WBDataLocations object.
// Used to reload information in the WBDataLocations object.
WBDataLocations.prototype.load = function (str) {
	if(this.errorCount > 2)
	{
		this.errorCount = 0;
		this.loadErrorCallback(this.errorString,this.longErrorWaitTime);
		this.dataLoadedCorrectly = false;
		return;
	}

	// Check to see if we are allowed to reload the object based on the update rate.
	if(this.time.checkForUpdate(this.lastReload,this.updateRate)) { this.data.load( "&ni=" + this.prefs.getIsNewInstance() ); }
	else if(this.dataLoadedCorrectly == true)
	{
		this.loadCallback();
	}
}

// Do not call this directly, only from an initialized WBLiveData object.
// Used to parse the information from the WBDataRequest object into the object variables.
WBDataLocations.prototype.dataFetched = function ()
{
	// make sure 'this' is in scope, if not call it again with the correct scope
    if(this != arguments.callee.currentScope){ return arguments.callee.apply(arguments.callee.currentScope, arguments); };

	try
	{
		var dataArray = this.data.request.responseText.split("|");

		// The length of the returned array is 27.
		// The length of dataArray[0] is 36
		// The index of the first '-' in dataArray[0] is 8
		// The index of the last '-' in dataArray[0] is 23
		// If any of these is wrong, reject the array.

		if(dataArray.length != 31 || dataArray[0].length != 36 || dataArray[0].indexOf("-") != 8 || dataArray[0].lastIndexOf("-") != 23)
		{
			this.errorCount++;
			this.loadErrorCallback(this.errorString,this.shortErrorWaitTime);
			this.dataLoadedCorrectly = false;
			return;
		}
		
		this.returnedGUID = dataArray[0];
		if(this.returnedGUID != this.prefs.getGUID()){ this.prefs.setGUID(this.returnedGUID); }

		this.pid = dataArray[1];

		this.locationURL = dataArray[2];
		this.stationURL = dataArray[3];
		this.liveDataURL = dataArray[4];
		this.forecastDataURL = dataArray[5];
		this.radarDataURL = dataArray[6];
		this.alertsDataURL = dataArray[7];
		this.camsDataURL = dataArray[8];
		this.moreTabContentURL = dataArray[9];
		this.linkRedirectURL = dataArray[10];
	
		this.newVersionAvailable = dataArray[11];
		this.newVersionNumber = dataArray[12];

		this.updateRate = parseInt(dataArray[13]);
		this.forecastMinUpdateRate = parseInt(dataArray[14]);
		this.forecastMaxUpdateRate = parseInt(dataArray[15]);
		this.radarMinUpdateRate = parseInt(dataArray[16]);
		this.radarMaxUpdateRate = parseInt(dataArray[17]);
		this.alertsMinUpdateRate = parseInt(dataArray[18]);
		this.alertsMaxUpdateRate = parseInt(dataArray[19]);
		this.liveMinUpdateRate = parseInt(dataArray[20]);
		this.liveMaxUpdateRate = parseInt(dataArray[21]);
		this.camsMinUpdateRate = parseInt(dataArray[22]);
		this.camsMaxUpdateRate = parseInt(dataArray[23]);
		this.moreTabMinUpdateRate = parseInt(dataArray[24]);
		this.moreTabMaxUpdateRate = parseInt(dataArray[25]);
		this.stateswitchtimer = parseInt(dataArray[26]);
		this.shortErrorWaitTime = parseInt(dataArray[27]);
		this.longErrorWaitTime = parseInt(dataArray[28]);
		this.dataErrorShortWaitTime = parseInt(dataArray[29]);
		this.dataErrorLongWaitTime = parseInt(dataArray[30]);
	}
	catch(e)
	{
		this.errorCount++;
		this.loadErrorCallback(this.errorString,this.shortErrorWaitTime);
		this.dataLoadedCorrectly = false;
		return;
	}
	
	this.lastReload = this.time.currentTime();
	this.errorCount = 0;
	this.dataLoadedCorrectly = true;
	this.loadCallback();
}
