/*
 * Copyright (c) 2006 AWS Convergence Technologies, Inc. 
 * All rights reserved.
 * Visit http://www.aws.com
 *
 * WBRadarData.js
 *
 * This scripts contains the WBRadarData resuable class. A WBRadarData
 * object takes care of loading and holding XML data from the XML_Radar call.
 */

// Object Definition
function WBRadarData(loadCallback,errorCallback,errorString,shortErrorWaitTime,longErrorWaitTime,URL,prefs,pid,minUpdateRate,maxUpdateRate,widgetState)
{
	this.time = new WBTime(); // New time object
	this.lastReload; // Last time the data was successfully updated
	this.minUpdateRate = minUpdateRate; // Rate at which the data should be updated in miliseconds (min boundary)
	this.maxUpdateRate = maxUpdateRate; // Rate at which the data should be updated in miliseconds (max boundary)

	// WBDataRequest object. Does the work in loading data from the ISAPI.
	this.data = new WBDataRequest(URL + "?PartnerId=" + pid + "&RequestType=5" + prefs.getZipCode() + "&uid=" + prefs.getGUID() + "&version=" + version,this.dataFetched,errorCallback);
	
	this.imgSrc; // Stores the local image source for this object
	this.thumbSrc; // Stores the local thumbnail image source

	this.loadCallback = loadCallback;		      // Data Loaded Callback
	this.loadErrorCallback = errorCallback;       // Data Error Callback
	this.errorString = errorString;               // String passed to the reload timer
	this.shortErrorWaitTime = shortErrorWaitTime; // Timeout for short error
	this.longErrorWaitTime = longErrorWaitTime;   // Timeout for long error
	this.errorCount = 0;                          // Counts the number of internal loading errors
	this.dataLoadedCorrectly = false;             // BOOL to see if we have correct data in the object or not
	this.prefs = prefs;
	this.widgetState = widgetState;

	this.dataFetched.currentScope = this; // Used when the dataFetched function has lost scope
}

// Do not call this directly, only from an initialized WBRadarData object.
// Used to reload current information in the WBRadarData object.
WBRadarData.prototype.load = function () {
	if(this.errorCount > 2)
	{
		this.errorCount = 0;
		this.loadErrorCallback(this.errorString,this.longErrorWaitTime);
		this.dataLoadedCorrectly = false;
		return;
	}
	var str;
	if(this.prefs.getType() == true)
	{
		str = '&cc=' + this.prefs.getZipCode();
	}
	else
	{
		str = '&zip=' + this.prefs.getZipCode();
	}
	// Check to see if we are allowed to reload the object based on the update rate.
	// state = 1 uses the active min update rate
	// otherwise use the max update rate
	if(this.widgetState.state)
	{
		if(this.time.checkForUpdate(this.lastReload,this.minUpdateRate)) { this.data.load(str); }
	}
	else
	{
		if(this.time.checkForUpdate(this.lastReload,this.maxUpdateRate)) { this.data.load(str); }
	}
}

// Do not call this directly, only from an initialized WBRadarData object.
// Used to parse the information from the WBDataRequest object into the object variables.
WBRadarData.prototype.dataFetched = function ()
{
	// make sure 'this' is in scope, if not call it again with the correct scope
    if(this != arguments.callee.currentScope){ return arguments.callee.apply(arguments.callee.currentScope, arguments); };

	try
	{
		var xmlDocNode = findChild(this.data.request.responseXML,awsweather);
		
		this.imgSrc = findChild(xmlDocNode,awsimage).firstChild.data;
		this.thumbSrc = findChild(xmlDocNode,awsthumbnail).firstChild.data;
	}
	catch(e)
	{
		this.errorCount++;
		this.loadErrorCallback(this.errorString,this.shortErrorWaitTime);
		this.dataLoadedCorrectly = false;
		return;
	}
	this.dataLoadedCorrectly = true;
	this.lastReload = this.time.currentTime(); // Set the last update time to now
	this.loadCallback();
}
