/*
 * Copyright (c) 2006 AWS Convergence Technologies, Inc. 
 * All rights reserved.
 * Visit http://www.aws.com
 *
 * WBStations.js
 *
 * This scripts contains the WBStations resuable class. A WBStations object
 * takes care of loading and holding cities and stations returned for the user
 * to choose from.
 */

// Object Definition
function WBStations(theCityURL,theStationsURL,cityCallback,cityErrorCallback,stationsCallback,stationsErrorCallback)
{
	this.cityURL = theCityURL; // Base url for cities
	this.stationURL = theStationsURL; // Base url for staitons

	this.cityList = new Array; // Array of returned cities
	this.cityZipCodeList = new Array; // Array of returned zip codes
	this.cityTypeList = new Array; // Array of returned station types

	this.stationsList = new Array; // Array of returned stations
	this.staitonCodes = new Array; // Array of returned station codes

	// WBDataRequest objects. Does the work in loading data.
	this.cityData = new WBDataRequest(this.cityURL,this.cityDataFetched,cityErrorCallback);
	this.stationData = new WBDataRequest(this.stationURL,this.stationsDataFetched,stationsErrorCallback);

	// Callbacks when making city requests
	this.loadCitiesCallback = cityCallback;
	this.loadCitiesErrorCallback = cityErrorCallback;

	// Callbacks when making station requests
	this.loadStationsCallback = stationsCallback;
	this.loadStationsErrorCallback = stationsErrorCallback;

	this.cityDataFetched.currentScope = this; // Used when the dataFetched function has lost scope.
	this.stationsDataFetched.currentScope = this; // Used when the dataFetched function has lost scope.
}

// Do not call this directly, only from an initialized WBDataLocations object.
// Used to reload information in the WBDataLocations object.
WBStations.prototype.loadCities = function (str) { this.cityData.load(str); }
WBStations.prototype.loadStations = function (str) { this.stationData.load(str); }

// Do not call this directly, only from an initialized WBLiveData object.
// Used to parse the information from the WBDataRequest object into the object variables.
WBStations.prototype.cityDataFetched = function ()
{
	// make sure 'this' is in scope, if not call it again with the correct scope
    if(this != arguments.callee.currentScope){ return arguments.callee.apply(arguments.callee.currentScope, arguments); };

	try
	{
		var uSDataArray = this.cityData.request.responseText.split("#");
		if(uSDataArray.length != 2 || this.cityData.request.responseText == '#')
		{
			this.loadCitiesErrorCallback();
			return;
		}
		else
		{
			delete this.cityList;
			delete this.cityZipCodeList;
			delete this.cityTypeList;
			this.cityList = new Array;
			this.cityZipCodeList = new Array;
			this.cityTypeList = new Array;

			if(uSDataArray[0] != '')
			{
				var uSCitiesArray = uSDataArray[0].split("|");
				
				for(var i=0; i < uSCitiesArray.length; i= i+3)
				{
					this.cityZipCodeList[this.cityZipCodeList.length] = uSCitiesArray[i];
					this.cityList[this.cityList.length] = uSCitiesArray[i+1] + ", " + uSCitiesArray[i+2] + ' (U.S.)';
					this.cityTypeList[this.cityTypeList.length] = false;
				}
				delete uSCitiesArray;
			}
			if(uSDataArray[1] != '')
			{
				var internationalCitiesArray = uSDataArray[1].split("|");
				
				for(var i=0; i < internationalCitiesArray.length; i= i+3)
				{
					this.cityZipCodeList[this.cityZipCodeList.length] = internationalCitiesArray[i];
					this.cityList[this.cityList.length] = internationalCitiesArray[i+1] + ", " + internationalCitiesArray[i+2] + ' (International)';
					this.cityTypeList[this.cityTypeList.length] = true;
				}
				delete internationalCitiesArray;
			}
		}
	}
	catch(e)
	{
		this.loadCitiesErrorCallback();
		return;
	}
	
	this.loadCitiesCallback();
}

// Do not call this directly, only from an initialized WBLiveData object.
// Used to parse the information from the WBDataRequest object into the object variables.
WBStations.prototype.stationsDataFetched = function ()
{
	// make sure 'this' is in scope, if not call it again with the correct scope
    if(this != arguments.callee.currentScope){ return arguments.callee.apply(arguments.callee.currentScope, arguments); };

	try
	{
		var stationsDataArray = this.stationData.request.responseText.split("|");
		
		delete this.stationsList;
		delete this.stationCodes;
		this.stationsList = new Array;
		this.stationCodes = new Array;
		for(var i=0; i < stationsDataArray.length; i= i+3)
		{
			if(stationsDataArray[i+2] != '')
			{
				this.stationsList[this.stationsList.length] = stationsDataArray[i+1] + " (" + stationsDataArray[i+2] + " miles away)";
			}
			else
			{
				this.stationsList[this.stationsList.length] = stationsDataArray[i+1];
			}
			this.stationCodes[this.stationsList.length] = stationsDataArray[i];
		}
		delete stationsDataArray;
	}
	catch(e)
	{
		this.loadStationsErrorCallback();
		return;
	}
	this.loadStationsCallback();
}
